@@ -1,13 +1,11 @@
 package Sah::Schema::pathname;
 
-our $DATE = '2018-06-04'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-07-12'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem path name',
-    'x.perl.coerce_rules' => [
-        'str_strip_trailing_slash',
-    ],
+    'x.completion' => ['filename'],
 }, {}];
 
 1;
@@ -25,7 +23,7 @@ Sah::Schema::pathname - Filesystem path name
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2018-06-04.
+This document describes version 0.006 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2019-07-12.
 
 =head1 HOMEPAGE
 
@@ -49,7 +47,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
